# 2023-04-04 - L2 Layer0 Bridge Forwarder

Deployment of `L2LayerZeroBridgeForwarder`, which is called by the Layer0 contracts in the child chains when state updates are pushed. This contract can be connected to a third one that can carry out tasks associated with the state update.

## Useful Files

- [Arbitrum mainnet addresses](./output/arbitrum.json)
- [Optimism mainnet addresses](./output/optimism.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Gnosis mainnet addresses](./output/gnosis.json)
- [BSC mainnet addresses](./output/bsc.json)
- [Avalanche mainnet addresses](./output/avalanche.json)
- [Polygon zkeVM mainnet addresses](./output/zkevm.json)
- [Base mainnet addresses](./output/base.json)
- [Goerli testnet addresses](./output/goerli.json)
- [Sepolia testnet addresses](./output/sepolia.json)
- [`L2LayerZeroBridgeForwarder` artifact](./artifact/L2LayerZeroBridgeForwarder.json)
